/*--------------------------------------------------------------------------*/
/*                                                                          */
/*                                                                          */
/*      ------------         Bit-Bucket Software <no-Inc>                   */
/*      \ 10001101 /         Writers and Distributors of                    */
/*       \ 011110 /          No-Cost<no-tm> Software.                       */
/*        \ 1011 /                                                          */
/*         ------                                                           */
/*                                                                          */
/*  Copyright (C) 1987, 1988, 1989 by Robert Hartman and Vincent Perriello  */
/*                                                                          */
/*                                                                          */
/*         Communications (FOSSIL) definitions for BinkleyTerm 2.10         */
/*                                                                          */
/*                                                                          */
/*    For complete  details  of the licensing restrictions, please refer    */
/*    to the License  agreement,  which  is published in its entirety in    */
/*    the MAKEFILE and BT.C, and also contained in the file LICENSE.210.    */
/*                                                                          */
/*    USE  OF THIS FILE IS SUBJECT TO THE  RESTRICTIONS CONTAINED IN THE    */
/*    BINKLEYTERM  LICENSING  AGREEMENT.  IF YOU DO NOT FIND THE TEXT OF    */
/*    THIS  AGREEMENT IN ANY OF THE  AFOREMENTIONED FILES,  OR IF YOU DO    */
/*    NOT HAVE THESE FILES,  YOU SHOULD  IMMEDIATELY CONTACT THE AUTHORS    */
/*    AT THE  ADDRESSES LISTED BELOW.  IN NO EVENT SHOULD YOU PROCEED TO    */
/*    USE   THIS  FILE  WITHOUT  HAVING   ACCEPTED  THE  TERMS  OF   THE    */
/*    BINKLEYTERM  LICENSING AGREEMENT,  OR SUCH OTHER  AGREEMENT AS YOU    */
/*    ARE ABLE TO REACH WITH THE AUTHORS.                                   */
/*                                                                          */
/*                                                                          */
/*    The Authors can be reached at the following addresses:                */
/*                                                                          */
/*    Robert C. Hartman                      Vincent E. Perriello           */
/*    Spark Software                         VEP Software                   */
/*    427-3 Amherst Street                   111 Carroll Street             */
/*    CS2032, Suite 232                      Naugatuck, CT 06770            */
/*    Nashua, NH 03061                                                      */
/*                                                                          */
/*    FidoNet 1:132/101                      FidoNet 1:141/491              */
/*    Data    (603) 888-8179                 Data    (203) 729-7569         */
/*                                                                          */
/*    Please feel free to contact us at any time to share your comments     */
/*    about our software and/or licensing policies.                         */
/*                                                                          */
/*--------------------------------------------------------------------------*/

#include "bink.h"

#ifdef NEVER
#define COM1            0
#define COM2            1
#define COM1_BASE       0x3f8
#define COM2_BASE       0x2f8
#define COM1_IMR	      0x10
#define COM2_IMR	      0x08
#define PASS_THRU_PORT  0x238
#define BAUD_150        0x020
#define BAUD_600        0x060
#define DELTA_CTS			0x01
#define DELTA_DSR			0x02
#define TRAIL_EDGE_RI	0x04
#define DELTA_CD			0x08
#define CTS					0x10 /* Bits for the Modem Status Register... */
#define DSR					0x20
#define RI					0x40
#define DCD					0x80    /* <--- some cheap modems use 0x20 for this */
#endif


#define BITS_7          0x02
#define BITS_8          0x03
#define STOP_1	         0x00
#define STOP_2	         0x04
#define ODD_PARITY      0x08
#define EVEN_PARITY     0x18
#define NO_PARITY       0x00
#define BAUD_300        0x040
#define BAUD_1200       0x080
#define BAUD_2400       0x0A0
#define BAUD_4800       0x0C0
#define BAUD_9600       0x0E0
#define BAUD_19200      0x000
#define BAUD_38400      0x020

/* Bit definitions for the Line Status Register */

#define DATA_READY	 	0x0100
#define OVERRUN_ERR	 	0x0200
#define PARITY_ERR	 	0x0400
#define FRAMING_ERR	 	0x0800
#define BREAK_INT		 	0x1000
#define TX_HOLD_EMPTY 	0x2000
#define TX_SHIFT_EMPTY	0x4000

/* Bit definitions for the driver flags */

#define USE_XON			0x01
#define USE_CTS			0x02
#define USE_DSR			0x04
#define OTHER_XON			0x08

#define BRK             0x01
#define MDM             0x02

struct CONTROL
	{
	int carrier_mask;
	int handshake_mask;
	};

struct baud_str {
	char *str;
	unsigned rate;
	};

extern struct pointers ctl;
extern struct _area area;


struct parse_list {
        int p_length;
        char *p_string;
        };

struct secure {
        char *rq_OKFile;
        char *rq_FILES;
        char *rq_About;
        char *rq_Template;
        char *sc_Inbound;
        int rq_Limit;
        };

/*--------------------------------------------------------------------------*/
/* MACROS and others required to interface Binkley's Zmodem to Maximus      */
/*--------------------------------------------------------------------------*/

#define local FALSE
#define Pascal pascal
#define Cdecl cdecl

#define PATHLEN           128   /* MAXIMUM length of any path\filename.ext */
#define LINELEN              80  /* Max. length of line to use             */
#define MAX_LINELEN (LINELEN*2)  /* Double the length of line which can    */

extern struct m_pointers prm;
extern char task_num;

#include <stdio.h>
#include "modem.h"
#include "proto.h"


/* Tidbits from OPUS.H: */

#include "prm.h"

/*--------------------------------------------------------------------------*/
/* System?.Bbs structure                                                    */
/* Please note that the `_sys' structure should NOT be considered stable.   */
/*--------------------------------------------------------------------------*/
struct _sys {
    word ls_caller;        /* Used in SYSTEM.BBS only: number of callers    */
    int  priv;             /* Minimum privs required to get to the area     */
    char msgpath[40];      /* Path to messages                              */
    char bbspath[40];      /* Path to BBS/GBS files *or* the barricade file */
    char hlppath[40];      /* Path to the user-help system                  */
    char uppath[40];       /* Path to the file upload sub-directory         */
    char filepath[40];     /* Path to the file download sub-directory       */
    word attrib;           /* Area attribute (see below)                    */
    byte lock;             /* NERF-CBCS Kludge!  Lock/key system...         */
    byte filler;           /* Free space for another kludge...              */
    long quote_pos;        /* Position of next usable byte in Quote file    */
};

/* The following flow constants were taken from FOSSIL.H: */

#define FLOW_txoff    0x01
#define FLOW_cts      0x02
#define FLOW_reserved 0x04
#define FLOW_rxoff    0x08


/* Hopefully, doing this will cause TC to optimize away some of the unused
   code! */
#define fullscreen  FALSE   /*PLF Tue  10-31-1989  16:03:01 */
#define un_attended FALSE   /*PLF Tue  10-31-1989  16:03:05 */

int cdecl r_cprintf(char *fmt, ...);    /*PLF Tue  10-31-1989  16:27:30 */
int cdecl r_cputs(char *str);           /*PLF Tue  10-31-1989  16:27:30 */
extern char ul_no_space;

#ifdef __TURBOC__   /*PLF Tue  10-31-1989  16:39:21 */
#define cprintf             r_cprintf
#define cputs               r_cputs
#endif

#define putch               putchar

#ifndef OS_2

/*
#define CARRIER             (mdm_status() & STATUS_dcd)
#define OUT_EMPTY()   (mdm_status() & STATUS_outempty)
#define OUT_FULL()    (!(mdm_status() & STATUS_roomavail))
#define MDM_AVAIL()   (mdm_status() & STATUS_anydata)
*/

#define CHAR_AVAIL()        (mdm_status() & DATA_READY)
#define DTR_OFF()           mdm_dtr(0)
#define DTR_ON()            mdm_dtr(1)
#define Com_Tx_NW(c)        mdm_pputc(c)
#define KEYPRESS()          (fossil_peek() != -1)
#define FOSSIL_PEEKKB()     fossil_peek()
#define READKB()            fossil_getcw()
#define READSCAN()          fossil_getcw()
#define FOSSIL_CHAR()       fossil_getcw()
#define XON_ENABLE()        mdm_flow(handshake_mask)
#define XON_DISABLE()       mdm_flow(handshake_mask & (~FLOW_txoff))
#define IN_XON_ENABLE()     mdm_flow(handshake_mask & FLOW_rxoff)
#define IN_XON_DISABLE()    mdm_flow(handshake_mask & (~FLOW_rxoff))
#define _BRK_ENABLE()       mdm_ctrlc(1)
#define _BRK_DISABLE()      mdm_ctrlc(0)
#define RECVD_BREAK()       mdm_ctrlc(1)
#define WRITE_ANSI(c)       fossil_putc(c)
#define FOSSIL_WATCHDOG(x)  mdm_watchdog(x)
#define WRITE_BIOS(c)       fossil_bputc(c)
#define CLEAR_OUTBOUND()    mdm_dump(0)
#define MODEM_IN()          mdm_ggetcw()
#define MODEM_STATUS()      mdm_status()
#define PEEKBYTE()          mdm_peek()
#define CLEAR_INBOUND()     mdm_dump(1)
#define handshake_mask      prm.handshake_mask

void BUFFER_BYTE(unsigned int c);
void UNBUFFER_BYTES(void);
void SENDBYTE(int c);

/*
   #define SENDBYTE(c)         mdm_pputcw(c)
   #define BUFFER_BYTE(c)      mdm_pputcw(c)
   #define UNBUFFER_BYTES()
*/

#else

#include "modem.h"

extern HCOMM hcModem;       /* owned by async.c */

/* translate binkley fossil stuff to my async package */
#define CARRIER            (ComIsOnline(hcModem))
#define CHAR_AVAIL()       ComInCount(hcModem)
#define OUT_EMPTY()        (ComOutCount(hcModem)==0)
#define OUT_FULL()         (ComOutSpace(hcModem)==0)
/* bsedev.h (and hence os2furbar.h)  define DTR_ON and DTR_OFF as
 * something completely different.  #undef them here.
 */
#undef DTR_ON
#undef DTR_OFF
#define DTR_OFF()          com_DTR_off()
#define DTR_ON()           com_DTR_on()
#define CLEAR_OUTBOUND()   ComPurge(hcModem, COMM_PURGE_TX)
#define CLEAR_INBOUND()    ComPurge(hcModem, COMM_PURGE_RX)
#define KEYPRESS()         kbhit()
#define READKB()           fossil_getcw()
#define FOSSIL_CHAR()      fossil_getcw()
#define XON_ENABLE()       com_XON_enable()
#define IN_XON_ENABLE()
#define XON_DISABLE()      com_XON_disable()
#define _BRK_DISABLE()
#define FOSSIL_WATCHDOG(x)
#define SENDBYTE(c)        ComPutc(hcModem, c)
#define BUFFER_BYTE(c)     ComPutc(hcModem, c)
#define UNBUFFER_BYTES()   ComTxWait(hcModem, 1L)   /* yield cpu for a moment */
#define MODEM_IN()         ComGetc(hcModem)
#define WRITE_ANSI(c)      putchar(c)
#define PEEKBYTE()         ComPeek(hcModem)
#define do_break(on)       com_break(on)
#endif

#define time_release()      Giveaway_Slice()
#define status_line         logit
#define cur_baud            baud
#define HoldAreaNameMunge(z) (".\\")  /* Always current directory */
#define adios(n)            quit(n)
#define bdos(dosfun,dosdx,dosal)    fprintf(stderr, "Dont use bdos " __FILE__ "(%d)\n", __LINE__)
#define bdosptr(dosfun,dosdx,dosal) fprintf(stderr, "Dont use bdos " __FILE__ "(%d)\n", __LINE__)

#define update_files(x)
#define clear_filetransfer()
#define invent_pkt_name(s)
#define check_netfile(s)    NULL
#define dexists(fname)      (access(fname, 0)==0)

#define is_arcmail(x,y)     FALSE
#define who_is_he           FALSE
#define netmail             FALSE
#define no_overdrive        TRUE
#define overwrite           FALSE
#define small_window        FALSE
#define REGISTER

#ifndef  TSYNC
#define  TSYNC 0x00ae
#endif

/* END OF FILE: com.h */
